@@ -1,5 +1,5 @@
 class Parser:
     def __init__(self, cookie):
         self.cookie = cookie
-        self.url = ""
+        self.url = ''
         self.selector = None
